<?php return array(
    'root' => array(
        'name' => 'nextcloud/3rdparty',
        'pretty_version' => 'dev-stable28',
        'version' => 'dev-stable28',
        'reference' => null,
        'type' => 'library',
        'install_path' => __DIR__ . '/../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'aws/aws-crt-php' => array(
            'pretty_version' => 'v1.2.6',
            'version' => '1.2.6.0',
            'reference' => 'a63485b65b6b3367039306496d49737cf1995408',
            'type' => 'library',
            'install_path' => __DIR__ . '/../aws/aws-crt-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'aws/aws-sdk-php' => array(
            'pretty_version' => '3.322.4',
            'version' => '3.322.4.0',
            'reference' => 'f6d2c64cb87d9e70ad99aeaffcd879a412d2ccb5',
            'type' => 'library',
            'install_path' => __DIR__ . '/../aws/aws-sdk-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bantu/ini-get-wrapper' => array(
            'pretty_version' => 'v1.0.1',
            'version' => '1.0.1.0',
            'reference' => '4770c7feab370c62e23db4f31c112b7c6d90aee2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../bantu/ini-get-wrapper',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'beberlei/assert' => array(
            'pretty_version' => 'v3.3.1',
            'version' => '3.3.1.0',
            'reference' => '5e721d7e937ca3ba2cdec1e1adf195f9e5188372',
            'type' => 'library',
            'install_path' => __DIR__ . '/../beberlei/assert',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'brick/math' => array(
            'pretty_version' => '0.9.2',
            'version' => '0.9.2.0',
            'reference' => 'dff976c2f3487d42c1db75a3b180e2b9f0e72ce0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../brick/math',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'cweagans/composer-patches' => array(
            'pretty_version' => '1.7.3',
            'version' => '1.7.3.0',
            'reference' => 'e190d4466fe2b103a55467dfa83fc2fecfcaf2db',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../cweagans/composer-patches',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'deepdiver/zipstreamer' => array(
            'pretty_version' => 'v2.0.3',
            'version' => '2.0.3.0',
            'reference' => 'b9d1f53453a5736285facb723252ea2169dc472e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../deepdiver/zipstreamer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'deepdiver1975/tarstreamer' => array(
            'pretty_version' => 'v2.1.0',
            'version' => '2.1.0.0',
            'reference' => '163052d7a076fd3dd54d4f50e1ff2705b72604db',
            'type' => 'library',
            'install_path' => __DIR__ . '/../deepdiver1975/tarstreamer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/cache' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'reference' => '1ca8f21980e770095a31456042471a57bc4c68fb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/dbal' => array(
            'pretty_version' => '3.7.0',
            'version' => '3.7.0.0',
            'reference' => '00d03067f07482f025d41ab55e4ba0db5eca2cdf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/dbal',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/deprecations' => array(
            'pretty_version' => '1.1.2',
            'version' => '1.1.2.0',
            'reference' => '4f2d4f2836e7ec4e7a8625e75c6aa916004db931',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/deprecations',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/event-manager' => array(
            'pretty_version' => '1.2.0',
            'version' => '1.2.0.0',
            'reference' => '95aa4cb529f1e96576f3fda9f5705ada4056a520',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/event-manager',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'doctrine/lexer' => array(
            'pretty_version' => '1.2.3',
            'version' => '1.2.3.0',
            'reference' => 'c268e882d4dbdd85e36e4ad69e02dc284f89d229',
            'type' => 'library',
            'install_path' => __DIR__ . '/../doctrine/lexer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'egulias/email-validator' => array(
            'pretty_version' => '3.2.5',
            'version' => '3.2.5.0',
            'reference' => 'b531a2311709443320c786feb4519cfaf94af796',
            'type' => 'library',
            'install_path' => __DIR__ . '/../egulias/email-validator',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fgrosse/phpasn1' => array(
            'pretty_version' => 'v2.3.0',
            'version' => '2.3.0.0',
            'reference' => '20299033c35f4300eb656e7e8e88cf52d1d6694e',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fgrosse/phpasn1',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fusonic/linq' => array(
            'pretty_version' => 'v1.1.0',
            'version' => '1.1.0.0',
            'reference' => '63520ef1470ca771acbd26871efb945dd4a7a5d8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fusonic/linq',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fusonic/opengraph' => array(
            'pretty_version' => 'v2.2.0',
            'version' => '2.2.0.0',
            'reference' => 'a63b588fbe56c175ae06e158f1513642653ee3c1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fusonic/opengraph',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'giggsey/libphonenumber-for-php-lite' => array(
            'pretty_version' => '8.13.12',
            'version' => '8.13.12.0',
            'reference' => '18ff58915092e837c25c9eb3eff33591713d3fea',
            'type' => 'library',
            'install_path' => __DIR__ . '/../giggsey/libphonenumber-for-php-lite',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/guzzle' => array(
            'pretty_version' => '7.5.0',
            'version' => '7.5.0.0',
            'reference' => 'b50a2a1251152e43f6a37f0fa053e730a67d25ba',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/guzzle',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/promises' => array(
            'pretty_version' => '1.5.2',
            'version' => '1.5.2.0',
            'reference' => 'b94b2807d85443f9719887892882d0329d1e2598',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/promises',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.4.5',
            'version' => '2.4.5.0',
            'reference' => '0454e12ef0cd597ccd2adb036f7bda4e7fface66',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/uri-template' => array(
            'pretty_version' => 'v0.2.0',
            'version' => '0.2.0.0',
            'reference' => 'db46525d6d8fee71033b73cc07160f3e5271a8ce',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/uri-template',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icewind/searchdav' => array(
            'pretty_version' => 'v3.1.0',
            'version' => '3.1.0.0',
            'reference' => '8339181df313361da4daee6cb1c7f144f67f8492',
            'type' => 'library',
            'install_path' => __DIR__ . '/../icewind/searchdav',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'icewind/streams' => array(
            'pretty_version' => 'v0.7.7',
            'version' => '0.7.7.0',
            'reference' => '64200fd7cfcc7f550c3c695c48d8fd8bba97fecb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../icewind/streams',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'justinrainbow/json-schema' => array(
            'pretty_version' => '5.2.10',
            'version' => '5.2.10.0',
            'reference' => '2ba9c8c862ecd5510ed16c6340aa9f6eadb4f31b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../justinrainbow/json-schema',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'laravel/serializable-closure' => array(
            'pretty_version' => 'v1.2.2',
            'version' => '1.2.2.0',
            'reference' => '47afb7fae28ed29057fdca37e16a84f90cc62fae',
            'type' => 'library',
            'install_path' => __DIR__ . '/../laravel/serializable-closure',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri' => array(
            'pretty_version' => '6.4.0',
            'version' => '6.4.0.0',
            'reference' => '09da64118eaf4c5d52f9923a1e6a5be1da52fd9a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri-interfaces' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'reference' => '667f150e589d65d79c89ffe662e426704f84224f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri-interfaces',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mexitek/phpcolors' => array(
            'pretty_version' => 'v1.0.4',
            'version' => '1.0.4.0',
            'reference' => '4043974240ca7dc3c2bec3c158588148b605b206',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mexitek/phpcolors',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'microsoft/azure-storage-blob' => array(
            'pretty_version' => '1.5.4',
            'version' => '1.5.4.0',
            'reference' => '1023ce1dbf062351a32ca5ec72ad1fd4a504f1bf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../microsoft/azure-storage-blob',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'microsoft/azure-storage-common' => array(
            'pretty_version' => '1.5.2',
            'version' => '1.5.2.0',
            'reference' => '8ca7b1bf4c9ca7c663e75a02a0035b05b37196a0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../microsoft/azure-storage-common',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mlocati/ip-lib' => array(
            'pretty_version' => '1.18.0',
            'version' => '1.18.0.0',
            'reference' => 'c77bd0b1f3e3956c7e9661e75cb1f54ed67d95d2',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mlocati/ip-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'mtdowling/jmespath.php' => array(
            'pretty_version' => '2.6.1',
            'version' => '2.6.1.0',
            'reference' => '9b87907a81b87bc76d19a7fb2d61e61486ee9edb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../mtdowling/jmespath.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nextcloud/3rdparty' => array(
            'pretty_version' => 'dev-stable28',
            'version' => 'dev-stable28',
            'reference' => null,
            'type' => 'library',
            'install_path' => __DIR__ . '/../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nextcloud/lognormalizer' => array(
            'pretty_version' => 'v1.0.0',
            'version' => '1.0.0.0',
            'reference' => '87445d69225c247aaff64643b1fc83c6d6df741f',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nextcloud/lognormalizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/archive_tar' => array(
            'pretty_version' => '1.4.14',
            'version' => '1.4.14.0',
            'reference' => '4d761c5334c790e45ef3245f0864b8955c562caa',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/archive_tar',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/console_getopt' => array(
            'pretty_version' => 'v1.4.3',
            'version' => '1.4.3.0',
            'reference' => 'a41f8d3e668987609178c7c4a9fe48fecac53fa0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/console_getopt',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/pear-core-minimal' => array(
            'pretty_version' => 'v1.10.10',
            'version' => '1.10.10.0',
            'reference' => '625a3c429d9b2c1546438679074cac1b089116a7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pear/pear-core-minimal',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pear/pear_exception' => array(
            'pretty_version' => 'v1.0.2',
            'version' => '1.0.2.0',
            'reference' => 'b14fbe2ddb0b9f94f5b24cf08783d599f776fff0',
            'type' => 'class',
            'install_path' => __DIR__ . '/../pear/pear_exception',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/async-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'php-http/client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'php-http/guzzle7-adapter' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'fb075a71dbfa4847cf0c2938c4e5a9c478ef8b01',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/guzzle7-adapter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/httplug' => array(
            'pretty_version' => '2.2.0',
            'version' => '2.2.0.0',
            'reference' => '191a0a1b41ed026b717421931f8d3bd2514ffbf9',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/httplug',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/promise' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '4c4c1f9b7289a2ec57cde7f1e9762a5789506f88',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-opencloud/openstack' => array(
            'pretty_version' => 'v3.2.1',
            'version' => '3.2.1.0',
            'reference' => '42e2d09b9368becb6fde6dac17854132fcf77a5c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-opencloud/openstack',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'phpseclib/phpseclib' => array(
            'pretty_version' => '2.0.47',
            'version' => '2.0.47.0',
            'reference' => 'b7d7d90ee7df7f33a664b4aea32d50a305d35adb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../phpseclib/phpseclib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'pimple/pimple' => array(
            'pretty_version' => 'v3.5.0',
            'version' => '3.5.0.0',
            'reference' => 'a94b3a4db7fb774b3d78dad2315ddc07629e1bed',
            'type' => 'library',
            'install_path' => __DIR__ . '/../pimple/pimple',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/cache' => array(
            'pretty_version' => '3.0.0',
            'version' => '3.0.0.0',
            'reference' => 'aa5030cfa5405eccfdcb1083ce040c2cb8d253bf',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/cache',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/clock' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'e41a24703d4560fd0acb709162f73b8adfc3aa0d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/clock',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/container' => array(
            'pretty_version' => '2.0.2',
            'version' => '2.0.2.0',
            'reference' => 'c71ecc56dfe541dbd90c5360474fbc405f8d5963',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/container',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/event-dispatcher' => array(
            'pretty_version' => '1.0.0',
            'version' => '1.0.0.0',
            'reference' => 'dbefd12671e8a14ec7f180cab83036ed26714bb0',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/event-dispatcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/event-dispatcher-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '2dfb5f6c5eff0e91e20e913f8c5452ed95b86621',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => '12ac7fcd07e5b077433f5f2bee95b3a771bf61be',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '1.0.1',
            'version' => '1.0.1.0',
            'reference' => 'f6561bf28d520154e4b0ec72be95418abe6d9363',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'psr/log' => array(
            'pretty_version' => '1.1.4',
            'version' => '1.1.4.0',
            'reference' => 'd49695b909c3b7628b6289db5479a1c204601f11',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/log',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/log-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0|2.0',
            ),
        ),
        'punic/calendar' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'punic/common' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'punic/punic' => array(
            'pretty_version' => '3.8.1',
            'version' => '3.8.1.0',
            'reference' => '142707201a246a9c2ea909605cd56177af87f961',
            'type' => 'library',
            'install_path' => __DIR__ . '/../punic/punic',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/collection' => array(
            'pretty_version' => '1.1.3',
            'version' => '1.1.3.0',
            'reference' => '28a5c4ab2f5111db6a60b2b4ec84057e0f43b9c1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/collection',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'ramsey/uuid' => array(
            'pretty_version' => '4.1.1',
            'version' => '4.1.1.0',
            'reference' => 'cd4032040a750077205918c86049aa0f43d22947',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ramsey/uuid',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'rhumsaa/uuid' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '4.1.1',
            ),
        ),
        'rsky/pear-core-min' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => 'v1.10.10',
            ),
        ),
        'sabre/dav' => array(
            'pretty_version' => '4.5.0',
            'version' => '4.5.0.0',
            'reference' => '7e40343e473f17eab3d1d6ca4ae3e1cdfc6e0fd8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/dav',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/event' => array(
            'pretty_version' => '5.1.4',
            'version' => '5.1.4.0',
            'reference' => 'd7da22897125d34d7eddf7977758191c06a74497',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/event',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/http' => array(
            'pretty_version' => '5.1.10',
            'version' => '5.1.10.0',
            'reference' => 'f9f3d1fba8916fa2f4ec25636c4fedc26cb94e02',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/http',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/uri' => array(
            'pretty_version' => '2.3.3',
            'version' => '2.3.3.0',
            'reference' => '7e0e7dfd0b7e14346a27eabd66e843a6e7f1812b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/vobject' => array(
            'pretty_version' => '4.5.4',
            'version' => '4.5.4.0',
            'reference' => 'a6d53a3e5bec85ed3dd78868b7de0f5b4e12f772',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/vobject',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'sabre/xml' => array(
            'pretty_version' => '2.2.6',
            'version' => '2.2.6.0',
            'reference' => '9cde7cdab1e50893cc83b037b40cd47bfde42a2b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../sabre/xml',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'scssphp/scssphp' => array(
            'pretty_version' => 'v1.11.0',
            'version' => '1.11.0.0',
            'reference' => '33749d12c2569bb24071f94e9af828662dabb068',
            'type' => 'library',
            'install_path' => __DIR__ . '/../scssphp/scssphp',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'spomky-labs/base64url' => array(
            'pretty_version' => 'v2.0.4',
            'version' => '2.0.4.0',
            'reference' => '7752ce931ec285da4ed1f4c5aa27e45e097be61d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spomky-labs/base64url',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'spomky-labs/cbor-php' => array(
            'pretty_version' => 'v2.0.1',
            'version' => '2.0.1.0',
            'reference' => '9776578000be884cd7864eeb7c37a4ac92d8c995',
            'type' => 'library',
            'install_path' => __DIR__ . '/../spomky-labs/cbor-php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'stecman/symfony-console-completion' => array(
            'pretty_version' => '0.11.0',
            'version' => '0.11.0.0',
            'reference' => 'a9502dab59405e275a9f264536c4e1cb61fc3518',
            'type' => 'library',
            'install_path' => __DIR__ . '/../stecman/symfony-console-completion',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/console' => array(
            'pretty_version' => 'v5.4.24',
            'version' => '5.4.24.0',
            'reference' => '560fc3ed7a43e6d30ea94a07d77f9a60b8ed0fb8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/console',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/css-selector' => array(
            'pretty_version' => 'v5.4.11',
            'version' => '5.4.11.0',
            'reference' => 'c1681789f059ab756001052164726ae88512ae3d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/css-selector',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/deprecation-contracts' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '26954b3d62a6c5fd0ea8a2a00c0353a14978d05c',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/deprecation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/dom-crawler' => array(
            'pretty_version' => 'v5.4.11',
            'version' => '5.4.11.0',
            'reference' => '0b900ca5576ecd59e08c76127e616667cfe427a7',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/dom-crawler',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/event-dispatcher' => array(
            'pretty_version' => 'v5.4.26',
            'version' => '5.4.26.0',
            'reference' => '5dcc00e03413f05c1e7900090927bb7247cb0aac',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/event-dispatcher',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/event-dispatcher-contracts' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => '7bc61cc2db649b4637d331240c5346dcc7708051',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/event-dispatcher-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/event-dispatcher-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '2.0',
            ),
        ),
        'symfony/http-foundation' => array(
            'pretty_version' => 'v5.4.25',
            'version' => '5.4.25.0',
            'reference' => 'f66be2706075c5f6325d2fe2b743a57fb5d23f6b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/http-foundation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/mailer' => array(
            'pretty_version' => 'v5.4.22',
            'version' => '5.4.22.0',
            'reference' => '6330cd465dfd8b7a07515757a1c37069075f7b0b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/mailer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/mime' => array(
            'pretty_version' => 'v5.4.19',
            'version' => '5.4.19.0',
            'reference' => 'a858429a9c704edc53fe057228cf9ca282ba48eb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/mime',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-ctype' => array(
            'pretty_version' => 'v1.23.0',
            'version' => '1.23.0.0',
            'reference' => '46cd95797e9df938fdd2b03693b5fca5e64b01ce',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-ctype',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-grapheme' => array(
            'pretty_version' => 'v1.23.1',
            'version' => '1.23.1.0',
            'reference' => '16880ba9c5ebe3642d1995ab866db29270b36535',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-grapheme',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-idn' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '639084e360537a19f9ee352433b84ce831f3d2da',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-idn',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-intl-normalizer' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '19bd1e4fcd5b91116f14d8533c57831ed00571b6',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-intl-normalizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-mbstring' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '8ad114f6b39e2c98a8b0e3bd907732c207c2b534',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-mbstring',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php72' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '869329b1e9894268a8a61dabb69153029b7a8c97',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php72',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php73' => array(
            'pretty_version' => 'v1.23.0',
            'version' => '1.23.0.0',
            'reference' => 'fba8933c384d6476ab14fb7b8526e5287ca7e010',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php73',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/polyfill-php80' => array(
            'pretty_version' => 'v1.27.0',
            'version' => '1.27.0.0',
            'reference' => '7a6ff3f1959bb01aefccb463a0f2cd3d3d2fd936',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/polyfill-php80',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/process' => array(
            'pretty_version' => 'v5.4.24',
            'version' => '5.4.24.0',
            'reference' => 'e3c46cc5689c8782944274bb30702106ecbe3b64',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/process',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/routing' => array(
            'pretty_version' => 'v5.4.25',
            'version' => '5.4.25.0',
            'reference' => '56bfc1394f7011303eb2e22724f9b422d3f14649',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/routing',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/service-contracts' => array(
            'pretty_version' => 'v3.0.2',
            'version' => '3.0.2.0',
            'reference' => 'd78d39c1599bd1188b8e26bb341da52c3c6d8a66',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/service-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/string' => array(
            'pretty_version' => 'v6.0.19',
            'version' => '6.0.19.0',
            'reference' => 'd9e72497367c23e08bf94176d2be45b00a9d232a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/string',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation' => array(
            'pretty_version' => 'v5.4.24',
            'version' => '5.4.24.0',
            'reference' => 'de237e59c5833422342be67402d487fbf50334ff',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-contracts' => array(
            'pretty_version' => 'v2.4.0',
            'version' => '2.4.0.0',
            'reference' => '95c812666f3e91db75385749fe219c5e494c7f95',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/translation-contracts',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/translation-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '2.3',
            ),
        ),
        'thecodingmachine/safe' => array(
            'pretty_version' => 'v1.3.3',
            'version' => '1.3.3.0',
            'reference' => 'a8ab0876305a4cdaef31b2350fcb9811b5608dbc',
            'type' => 'library',
            'install_path' => __DIR__ . '/../thecodingmachine/safe',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'wapmorgan/mp3info' => array(
            'pretty_version' => '0.1.0',
            'version' => '0.1.0.0',
            'reference' => 'f4e3b0d606732f667729c116e1baa4f845a65f9d',
            'type' => 'library',
            'install_path' => __DIR__ . '/../wapmorgan/mp3info',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/cose-lib' => array(
            'pretty_version' => 'v3.3.9',
            'version' => '3.3.9.0',
            'reference' => 'ed172d2dc1a6b87b5c644c07c118cd30c1b3819b',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/cose-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/metadata-service' => array(
            'pretty_version' => 'v3.3.9',
            'version' => '3.3.9.0',
            'reference' => '8488d3a832a38cc81c670fce05de1e515c6e64b1',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/metadata-service',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'web-auth/webauthn-lib' => array(
            'pretty_version' => 'v3.3.9',
            'version' => '3.3.9.0',
            'reference' => '04b98ee3d39cb79dad68a7c15c297c085bf66bfe',
            'type' => 'library',
            'install_path' => __DIR__ . '/../web-auth/webauthn-lib',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
